#ifndef __TASK_GPIO_H__
#define __TASK_GPIO_H__

#include "memory.h"
#include "xburst_types.h"

/* Special task versions of GPIO operations. */

#define TASK_GPIO_PXPIN(n)	(TASK_GPIO_BASE + (0x00 + (n)*0x100)) /* PIN Level Register */
#define TASK_GPIO_PXDAT(n)	(TASK_GPIO_BASE + (0x10 + (n)*0x100)) /* Port Data Register */
#define TASK_GPIO_PXDATS(n)	(TASK_GPIO_BASE + (0x14 + (n)*0x100)) /* Port Data Set Register */
#define TASK_GPIO_PXDATC(n)	(TASK_GPIO_BASE + (0x18 + (n)*0x100)) /* Port Data Clear Register */

#define TASK_GPIO_PXDIR(n)	(TASK_GPIO_BASE + (0x60 + (n)*0x100)) /* Direction Register */
#define TASK_GPIO_PXDIRS(n)	(TASK_GPIO_BASE + (0x64 + (n)*0x100)) /* Direction Set Register */
#define TASK_GPIO_PXDIRC(n)	(TASK_GPIO_BASE + (0x68 + (n)*0x100)) /* Direction Clear Register */

#define TASK_REG_GPIO_PXPIN(n)	REG32(TASK_GPIO_PXPIN((n)))
#define TASK_REG_GPIO_PXDAT(n)	REG32(TASK_GPIO_PXDAT((n)))
#define TASK_REG_GPIO_PXDATS(n)	REG32(TASK_GPIO_PXDATS((n)))
#define TASK_REG_GPIO_PXDATC(n)	REG32(TASK_GPIO_PXDATC((n)))

#define TASK_REG_GPIO_PXDIR(n)	REG32(TASK_GPIO_PXDIR((n)))
#define TASK_REG_GPIO_PXDIRS(n)	REG32(TASK_GPIO_PXDIRS((n)))
#define TASK_REG_GPIO_PXDIRC(n)	REG32(TASK_GPIO_PXDIRC((n)))

void task_gpio_init(uint8_t task);
void task_gpio_as_input(uint8_t pin);
void task_gpio_as_output(uint8_t pin);
void task_gpio_set_pin(uint8_t pin);
void task_gpio_clear_pin(uint8_t pin);
int task_gpio_get_pin(uint8_t pin);

#endif /* __TASK_GPIO_H__ */
